.. _camera_description:

.. currentmodule:: ctapipe.instrument

Camera Description
==================

The `CameraDescription` contains classes holding information about the
Cherenkov camera, namely the `CameraGeometry` and `CameraReadout` classes.


.. toctree::
  :maxdepth: 1

  camera_geometry
  camera_readout